'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _nats = require('./nats');

var _nats2 = _interopRequireDefault(_nats);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _postgres = require('./postgres');

var _postgres2 = _interopRequireDefault(_postgres);

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _redis = require('./redis');

var _redis2 = _interopRequireDefault(_redis);

var _s = require('./s3');

var _s2 = _interopRequireDefault(_s);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var register = function register(server, pluginOptions, next) {
  var env = process.env.NODE_ENV || 'DEV';

  var defaultOptions = {
    path: '/status',
    health_checks: [],
    custom_health_checks: [],
    feature_health_checks: [],
    custom_feature_health_checks: []
  };
  var options = _ramda2.default.merge(defaultOptions, pluginOptions);

  server.register({
    register: require('hapi-and-healthy'),
    options: {
      env: env,
      name: _package2.default.name,
      path: options.path,
      test: {
        node: _ramda2.default.concat(createHealthCheckArray(options.health_checks), options.custom_health_checks),
        features: _ramda2.default.concat(createHealthCheckArray(options.feature_health_checks), options.custom_feature_health_checks)
      },
      usage: true,
      version: _package2.default.version
    }
  }, function (err) {
    if (err) {
      console.error('Error when registering plugin hapi-and-healthy : ' + err);
      throw err;
    }
  });

  next();
};

register.attributes = {
  pkg: _package2.default
};

var createHealthCheckArray = function createHealthCheckArray(healthChecks) {
  if (!healthChecks || !Array.isArray(healthChecks)) {
    return [];
  }

  var result = [];
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = (0, _getIterator3.default)(healthChecks), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var check = _step.value;

      switch (check.type) {
        case 'postgres':
          result.push(new _postgres2.default(check.options).createHealthCheck());
          break;
        case 'redis':
          result.push(new _redis2.default(check.options).createHealthCheck());
          break;
        case 's3':
          result.push(new _s2.default(check.options).createHealthCheck());
          break;
        case 'nats':
          result.push(new _nats2.default(check.options).createHealthCheck());
          break;
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return result;
};

exports.default = register;